import importlib.resources

from playwright.async_api import Page as AsyncPage
from playwright.sync_api import Page as SyncPage


__all__ = ['load_sync', 'load_async']

SCRIPT = importlib.resources.read_text(package=__package__, resource="spy.min.js")


def load_sync(page: SyncPage):
    """teaches synchronous playwright Page to be stealthy like a ninja!"""
    page.add_init_script(SCRIPT)


async def load_async(page: AsyncPage):
    """teaches asynchronous playwright Page to be stealthy like a ninja!"""
    await page.add_init_script(SCRIPT)



from pathlib import Path

import setuptools

version = Path("VERSION").read_text().strip()
long_description = Path("README.md").read_text()

setuptools.setup(
    name="playwright-spy",
    version=version,
    author="dsppman",
    author_email="dsppman@gmail.com",
    description="A plugin for playwright to prevent detection.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/dsppman/playwright-spy",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
    python_requires=">=3.5",
    install_requires=[
        "playwright>=1.15",
    ]
)